@@ -15,8 +15,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with the software; see the file COPYING. If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #include <config.h>
@@ -251,7 +251,7 @@ fill_image_buffer_from_file (cairo_t *cr, const char *filePath)
   tmp_cr = cairo_create (tmp_surface);
   rsvg_handle_render_cairo (handle, tmp_cr);
   cairo_destroy (tmp_cr);
-  rsvg_handle_free (handle);
+  g_object_unref (handle);
   return tmp_surface;
 }
 
