@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  */
 
@@ -797,12 +797,13 @@ static void
 cb_toggle_tree (GtkAction *action, gpointer data)
 {
 	ProcData *procdata = static_cast<ProcData*>(data);
-	MateConfClient *client = procdata->client;
+	GSettings *settings = procdata->settings;
 	gboolean show;
 
 	show = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action));
 	if (show == procdata->config.show_tree)
 		return;
 
-	mateconf_client_set_bool (client, "/apps/procman/show_tree", show, NULL);
+	g_settings_set_boolean (settings, "show-tree", show);
 }
+
