@@ -40,6 +40,7 @@ void
 PrettyTable::on_application_opened(MatewnckScreen* screen, MatewnckApplication* app, gpointer data)
 {
   PrettyTable * const that = static_cast<PrettyTable*>(data);
+  FILE *f;
 
   pid_t pid = matewnck_application_get_pid(app);
 
@@ -50,8 +51,13 @@ PrettyTable::on_application_opened(MatewnckScreen* screen, MatewnckApplication*
 
 
   Glib::RefPtr<Gdk::Pixbuf> icon;
-
-  icon = that->theme->load_icon(icon_name, APP_ICON_SIZE, Gtk::ICON_LOOKUP_USE_BUILTIN);
+  
+  // Make sure that icon_name is a valid symlink before loading.
+  f = fopen (icon_name, "r");
+  if (f != NULL) {
+    fclose (f);
+    icon = that->theme->load_icon(icon_name, APP_ICON_SIZE, Gtk::ICON_LOOKUP_USE_BUILTIN);
+  }
 
   if (not icon) {
     icon = Glib::wrap(matewnck_application_get_icon(app), /* take_copy */ true);
