@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  */
 #ifndef _PROCMAN_PROCMAN_H_
@@ -23,8 +23,8 @@
 #include <glibmm/refptr.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <glib.h>
+#include <gio/gio.h>
 #include <gtk/gtk.h>
-#include <mateconf/mateconf-client.h>
 #include <glibtop/cpu.h>
 
 #include <time.h>
@@ -40,6 +40,8 @@ struct LoadGraph;
 #include "smooth_refresh.h"
 #include "prettytable.h"
 
+#define GSM_GSETTINGS_SCHEMA "org.mate.system-monitor"
+
 enum
 {
 	ALL_PROCESSES,
@@ -72,8 +74,8 @@ struct ProcConfig
 {
 	gint		width;
 	gint		height;
-        gboolean	show_kill_warning;
-        gboolean	show_tree;
+	gboolean    show_kill_warning;
+	gboolean    show_tree;
 	gboolean	show_all_fs;
 	int		update_interval;
  	int		graph_update_interval;
@@ -206,8 +208,8 @@ struct ProcData
 
 	PrettyTable	pretty_table;
 
-	MateConfClient	*client;
-	GtkWidget	*app;
+	GSettings       *settings;
+	GtkWidget	    *app;
 	GtkUIManager	*menu;
 
 	unsigned	frequency;
@@ -224,8 +226,8 @@ private:
 };
 
 void		procman_save_config (ProcData *data);
-void		procman_save_tree_state (MateConfClient *client, GtkWidget *tree, const gchar *prefix);
-gboolean	procman_get_tree_state (MateConfClient *client, GtkWidget *tree, const gchar *prefix);
+void        procman_save_tree_state (GSettings *settings, GtkWidget *tree, const gchar *prefix);
+gboolean    procman_get_tree_state (GSettings *settings, GtkWidget *tree, const gchar *prefix);
 
 
 
