@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  */
 
@@ -90,9 +90,9 @@ cb_columns_changed(GtkTreeView *treeview, gpointer user_data)
 {
 	ProcData * const procdata = static_cast<ProcData*>(user_data);
 
-	procman_save_tree_state(procdata->client,
+	procman_save_tree_state(procdata->settings,
 				GTK_WIDGET(treeview),
-				"/apps/procman/proctree");
+				"proctree");
 }
 
 
@@ -392,7 +392,7 @@ proctable_new (ProcData * const procdata)
 
 	set_proctree_reorderable(procdata);
 
-	procman_get_tree_state (procdata->client, proctree, "/apps/procman/proctree");
+	procman_get_tree_state (procdata->settings, proctree, "proctree");
 
 	/* Override column settings by hiding this column if it's meaningless: */
 	if (!can_show_security_context_column ()) {
